# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: model/ray/serve.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15model/ray/serve.proto\x12\tray.serve\"\xcc\x06\n\x11\x41utoscalingConfig\x12!\n\x0cmin_replicas\x18\x01 \x01(\rR\x0bminReplicas\x12!\n\x0cmax_replicas\x18\x02 \x01(\rR\x0bmaxReplicas\x12,\n\x12metrics_interval_s\x18\x03 \x01(\x01R\x10metricsIntervalS\x12+\n\x12look_back_period_s\x18\x04 \x01(\x01R\x0flookBackPeriodS\x12)\n\x10smoothing_factor\x18\x05 \x01(\x01R\x0fsmoothingFactor\x12*\n\x11\x64ownscale_delay_s\x18\x06 \x01(\x01R\x0f\x64ownscaleDelayS\x12&\n\x0fupscale_delay_s\x18\x07 \x01(\x01R\rupscaleDelayS\x12.\n\x10initial_replicas\x18\x08 \x01(\rH\x00R\x0finitialReplicas\x88\x01\x01\x12=\n\x18upscale_smoothing_factor\x18\t \x01(\x01H\x01R\x16upscaleSmoothingFactor\x88\x01\x01\x12\x41\n\x1a\x64ownscale_smoothing_factor\x18\n \x01(\x01H\x02R\x18\x64ownscaleSmoothingFactor\x88\x01\x01\x12\x33\n\x16_serialized_policy_def\x18\x0b \x01(\x0cR\x13SerializedPolicyDef\x12\x17\n\x07_policy\x18\x0c \x01(\tR\x06Policy\x12\x36\n\x17target_ongoing_requests\x18\r \x01(\x01R\x15targetOngoingRequests\x12.\n\x10upscaling_factor\x18\x0e \x01(\x01H\x03R\x0fupscalingFactor\x88\x01\x01\x12\x32\n\x12\x64ownscaling_factor\x18\x0f \x01(\x01H\x04R\x11\x64ownscalingFactor\x88\x01\x01\x42\x13\n\x11_initial_replicasB\x1b\n\x19_upscale_smoothing_factorB\x1d\n\x1b_downscale_smoothing_factorB\x13\n\x11_upscaling_factorB\x15\n\x13_downscaling_factor\"\xeb\x01\n\rLoggingConfig\x12\x33\n\x08\x65ncoding\x18\x01 \x01(\x0e\x32\x17.ray.serve.EncodingTypeR\x08\x65ncoding\x12\x1b\n\tlog_level\x18\x02 \x01(\tR\x08logLevel\x12\x19\n\x08logs_dir\x18\x03 \x01(\tR\x07logsDir\x12*\n\x11\x65nable_access_log\x18\x04 \x01(\x08R\x0f\x65nableAccessLog\x12\x41\n\x1d\x61\x64\x64itional_log_standard_attrs\x18\x05 \x03(\tR\x1a\x61\x64\x64itionalLogStandardAttrs\"\x86\x06\n\x10\x44\x65ploymentConfig\x12!\n\x0cnum_replicas\x18\x01 \x01(\x05R\x0bnumReplicas\x12\x30\n\x14max_ongoing_requests\x18\x02 \x01(\x05R\x12maxOngoingRequests\x12.\n\x13max_queued_requests\x18\x03 \x01(\x05R\x11maxQueuedRequests\x12\x1f\n\x0buser_config\x18\x04 \x01(\x0cR\nuserConfig\x12@\n\x1dgraceful_shutdown_wait_loop_s\x18\x05 \x01(\x01R\x19gracefulShutdownWaitLoopS\x12=\n\x1bgraceful_shutdown_timeout_s\x18\x06 \x01(\x01R\x18gracefulShutdownTimeoutS\x12\x31\n\x15health_check_period_s\x18\x07 \x01(\x01R\x12healthCheckPeriodS\x12\x33\n\x16health_check_timeout_s\x18\x08 \x01(\x01R\x13healthCheckTimeoutS\x12*\n\x11is_cross_language\x18\t \x01(\x08R\x0fisCrossLanguage\x12N\n\x13\x64\x65ployment_language\x18\n \x01(\x0e\x32\x1d.ray.serve.DeploymentLanguageR\x12\x64\x65ploymentLanguage\x12K\n\x12\x61utoscaling_config\x18\x0b \x01(\x0b\x32\x1c.ray.serve.AutoscalingConfigR\x11\x61utoscalingConfig\x12\x18\n\x07version\x18\x0c \x01(\tR\x07version\x12?\n\x1cuser_configured_option_names\x18\r \x03(\tR\x19userConfiguredOptionNames\x12?\n\x0elogging_config\x18\x0e \x01(\x0b\x32\x18.ray.serve.LoggingConfigR\rloggingConfig\"\xc8\x02\n\x0fRequestMetadata\x12\x1d\n\nrequest_id\x18\x01 \x01(\tR\trequestId\x12.\n\x13internal_request_id\x18\x02 \x01(\tR\x11internalRequestId\x12\x1f\n\x0b\x63\x61ll_method\x18\x03 \x01(\tR\ncallMethod\x12\x41\n\x07\x63ontext\x18\x04 \x03(\x0b\x32\'.ray.serve.RequestMetadata.ContextEntryR\x07\x63ontext\x12\x30\n\x14multiplexed_model_id\x18\x05 \x01(\tR\x12multiplexedModelId\x12\x14\n\x05route\x18\x06 \x01(\tR\x05route\x1a:\n\x0c\x43ontextEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\"$\n\x0eRequestWrapper\x12\x12\n\x04\x62ody\x18\x01 \x01(\x0cR\x04\x62ody\"Y\n\rUpdatedObject\x12\'\n\x0fobject_snapshot\x18\x01 \x01(\x0cR\x0eobjectSnapshot\x12\x1f\n\x0bsnapshot_id\x18\x02 \x01(\x05R\nsnapshotId\"\xbb\x01\n\x0fLongPollRequest\x12\x62\n\x14keys_to_snapshot_ids\x18\x01 \x03(\x0b\x32\x31.ray.serve.LongPollRequest.KeysToSnapshotIdsEntryR\x11keysToSnapshotIds\x1a\x44\n\x16KeysToSnapshotIdsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\x05R\x05value:\x02\x38\x01\"\xc5\x01\n\x0eLongPollResult\x12V\n\x0fupdated_objects\x18\x01 \x03(\x0b\x32-.ray.serve.LongPollResult.UpdatedObjectsEntryR\x0eupdatedObjects\x1a[\n\x13UpdatedObjectsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12.\n\x05value\x18\x02 \x01(\x0b\x32\x18.ray.serve.UpdatedObjectR\x05value:\x02\x38\x01\"\xc1\x01\n\x0c\x45ndpointInfo\x12#\n\rendpoint_name\x18\x01 \x01(\tR\x0c\x65ndpointName\x12\x14\n\x05route\x18\x02 \x01(\tR\x05route\x12;\n\x06\x63onfig\x18\x03 \x03(\x0b\x32#.ray.serve.EndpointInfo.ConfigEntryR\x06\x63onfig\x1a\x39\n\x0b\x43onfigEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\"\xa9\x01\n\x0b\x45ndpointSet\x12\x43\n\tendpoints\x18\x01 \x03(\x0b\x32%.ray.serve.EndpointSet.EndpointsEntryR\tendpoints\x1aU\n\x0e\x45ndpointsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12-\n\x05value\x18\x02 \x01(\x0b\x32\x17.ray.serve.EndpointInfoR\x05value:\x02\x38\x01\"%\n\rActorNameList\x12\x14\n\x05names\x18\x01 \x03(\tR\x05names\"^\n\x14\x44\x65ploymentTargetInfo\x12#\n\rreplica_names\x18\x01 \x03(\tR\x0creplicaNames\x12!\n\x0cis_available\x18\x02 \x01(\x08R\x0bisAvailable\"\xd1\x02\n\x11\x44\x65ploymentVersion\x12!\n\x0c\x63ode_version\x18\x01 \x01(\tR\x0b\x63odeVersion\x12H\n\x11\x64\x65ployment_config\x18\x02 \x01(\x0b\x32\x1b.ray.serve.DeploymentConfigR\x10\x64\x65ploymentConfig\x12*\n\x11ray_actor_options\x18\x03 \x01(\tR\x0frayActorOptions\x12\x36\n\x17placement_group_bundles\x18\x04 \x01(\tR\x15placementGroupBundles\x12\x38\n\x18placement_group_strategy\x18\x05 \x01(\tR\x16placementGroupStrategy\x12\x31\n\x15max_replicas_per_node\x18\x06 \x01(\x05R\x12maxReplicasPerNode\"\xf5\x02\n\rReplicaConfig\x12.\n\x13\x64\x65ployment_def_name\x18\x01 \x01(\tR\x11\x64\x65ploymentDefName\x12%\n\x0e\x64\x65ployment_def\x18\x02 \x01(\x0cR\rdeploymentDef\x12\x1b\n\tinit_args\x18\x03 \x01(\x0cR\x08initArgs\x12\x1f\n\x0binit_kwargs\x18\x04 \x01(\x0cR\ninitKwargs\x12*\n\x11ray_actor_options\x18\x05 \x01(\tR\x0frayActorOptions\x12\x36\n\x17placement_group_bundles\x18\x06 \x01(\tR\x15placementGroupBundles\x12\x38\n\x18placement_group_strategy\x18\x07 \x01(\tR\x16placementGroupStrategy\x12\x31\n\x15max_replicas_per_node\x18\x08 \x01(\x05R\x12maxReplicasPerNode\"\xb5\x03\n\x0e\x44\x65ploymentInfo\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12H\n\x11\x64\x65ployment_config\x18\x02 \x01(\x0b\x32\x1b.ray.serve.DeploymentConfigR\x10\x64\x65ploymentConfig\x12?\n\x0ereplica_config\x18\x03 \x01(\x0b\x32\x18.ray.serve.ReplicaConfigR\rreplicaConfig\x12\"\n\rstart_time_ms\x18\x04 \x01(\x03R\x0bstartTimeMs\x12\x1d\n\nactor_name\x18\x05 \x01(\tR\tactorName\x12\x18\n\x07version\x18\x06 \x01(\tR\x07version\x12\x1e\n\x0b\x65nd_time_ms\x18\x07 \x01(\x03R\tendTimeMs\x12\'\n\x0ftarget_capacity\x18\x08 \x01(\x01R\x0etargetCapacity\x12^\n\x19target_capacity_direction\x18\t \x01(\x0e\x32\".ray.serve.TargetCapacityDirectionR\x17targetCapacityDirection\"k\n\x0f\x44\x65ploymentRoute\x12\x42\n\x0f\x64\x65ployment_info\x18\x01 \x01(\x0b\x32\x19.ray.serve.DeploymentInfoR\x0e\x64\x65ploymentInfo\x12\x14\n\x05route\x18\x02 \x01(\tR\x05route\"^\n\x13\x44\x65ploymentRouteList\x12G\n\x11\x64\x65ployment_routes\x18\x01 \x03(\x0b\x32\x1a.ray.serve.DeploymentRouteR\x10\x64\x65ploymentRoutes\"\xc4\x01\n\x14\x44\x65ploymentStatusInfo\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x33\n\x06status\x18\x02 \x01(\x0e\x32\x1b.ray.serve.DeploymentStatusR\x06status\x12\x18\n\x07message\x18\x03 \x01(\tR\x07message\x12I\n\x0estatus_trigger\x18\x04 \x01(\x0e\x32\".ray.serve.DeploymentStatusTriggerR\rstatusTrigger\"s\n\x18\x44\x65ploymentStatusInfoList\x12W\n\x17\x64\x65ployment_status_infos\x18\x01 \x03(\x0b\x32\x1f.ray.serve.DeploymentStatusInfoR\x15\x64\x65ploymentStatusInfos\"\x9a\x01\n\x15\x41pplicationStatusInfo\x12\x34\n\x06status\x18\x01 \x01(\x0e\x32\x1c.ray.serve.ApplicationStatusR\x06status\x12\x18\n\x07message\x18\x02 \x01(\tR\x07message\x12\x31\n\x14\x64\x65ployment_timestamp\x18\x03 \x01(\x01R\x13\x64\x65ploymentTimestamp\"\xbb\x01\n\x0eStatusOverview\x12?\n\napp_status\x18\x01 \x01(\x0b\x32 .ray.serve.ApplicationStatusInfoR\tappStatus\x12T\n\x13\x64\x65ployment_statuses\x18\x02 \x01(\x0b\x32#.ray.serve.DeploymentStatusInfoListR\x12\x64\x65ploymentStatuses\x12\x12\n\x04name\x18\x03 \x01(\tR\x04name\"\x19\n\x17ListApplicationsRequest\"G\n\x18ListApplicationsResponse\x12+\n\x11\x61pplication_names\x18\x01 \x03(\tR\x10\x61pplicationNames\"\x10\n\x0eHealthzRequest\"+\n\x0fHealthzResponse\x12\x18\n\x07message\x18\x01 \x01(\tR\x07message\"L\n\x12UserDefinedMessage\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x10\n\x03\x66oo\x18\x02 \x01(\tR\x03\x66oo\x12\x10\n\x03num\x18\x03 \x01(\x03R\x03num\"H\n\x13UserDefinedResponse\x12\x1a\n\x08greeting\x18\x01 \x01(\tR\x08greeting\x12\x15\n\x06num_x2\x18\x02 \x01(\x03R\x05numX2\"\x15\n\x13UserDefinedMessage2\"2\n\x14UserDefinedResponse2\x12\x1a\n\x08greeting\x18\x01 \x01(\tR\x08greeting\"T\n\x0c\x46ruitAmounts\x12\x16\n\x06orange\x18\x01 \x01(\x03R\x06orange\x12\x14\n\x05\x61pple\x18\x02 \x01(\x03R\x05\x61pple\x12\x16\n\x06\x62\x61nana\x18\x03 \x01(\x03R\x06\x62\x61nana\"\"\n\nFruitCosts\x12\x14\n\x05\x63osts\x18\x01 \x01(\x02R\x05\x63osts\"\x1f\n\tArrayData\x12\x12\n\x04nums\x18\x01 \x03(\x02R\x04nums\" \n\nStringData\x12\x12\n\x04\x64\x61ta\x18\x01 \x01(\tR\x04\x64\x61ta\"%\n\x0bModelOutput\x12\x16\n\x06output\x18\x01 \x01(\x02R\x06output\"\xb8\x02\n\x0e\x44\x65ploymentArgs\x12\'\n\x0f\x64\x65ployment_name\x18\x01 \x01(\tR\x0e\x64\x65ploymentName\x12+\n\x11\x64\x65ployment_config\x18\x02 \x01(\x0cR\x10\x64\x65ploymentConfig\x12%\n\x0ereplica_config\x18\x03 \x01(\x0cR\rreplicaConfig\x12&\n\x0f\x64\x65ployer_job_id\x18\x04 \x01(\tR\rdeployerJobId\x12&\n\x0croute_prefix\x18\x05 \x01(\tH\x00R\x0broutePrefix\x88\x01\x01\x12\x18\n\x07ingress\x18\x06 \x01(\x08R\x07ingress\x12 \n\tdocs_path\x18\x07 \x01(\tH\x01R\x08\x64ocsPath\x88\x01\x01\x42\x0f\n\r_route_prefixB\x0c\n\n_docs_path*\"\n\x0c\x45ncodingType\x12\x08\n\x04TEXT\x10\x00\x12\x08\n\x04JSON\x10\x01**\n\x12\x44\x65ploymentLanguage\x12\n\n\x06PYTHON\x10\x00\x12\x08\n\x04JAVA\x10\x01*6\n\x17TargetCapacityDirection\x12\t\n\x05UNSET\x10\x00\x12\x06\n\x02UP\x10\x01\x12\x08\n\x04\x44OWN\x10\x02*\xdb\x01\n\x10\x44\x65ploymentStatus\x12\x1e\n\x1a\x44\x45PLOYMENT_STATUS_UPDATING\x10\x00\x12\x1d\n\x19\x44\x45PLOYMENT_STATUS_HEALTHY\x10\x01\x12\x1f\n\x1b\x44\x45PLOYMENT_STATUS_UNHEALTHY\x10\x02\x12#\n\x1f\x44\x45PLOYMENT_STATUS_DEPLOY_FAILED\x10\x03\x12\x1f\n\x1b\x44\x45PLOYMENT_STATUS_UPSCALING\x10\x04\x12!\n\x1d\x44\x45PLOYMENT_STATUS_DOWNSCALING\x10\x05*\xfe\x03\n\x17\x44\x65ploymentStatusTrigger\x12)\n%DEPLOYMENT_STATUS_TRIGGER_UNSPECIFIED\x10\x00\x12\x33\n/DEPLOYMENT_STATUS_TRIGGER_CONFIG_UPDATE_STARTED\x10\x01\x12\x35\n1DEPLOYMENT_STATUS_TRIGGER_CONFIG_UPDATE_COMPLETED\x10\x02\x12/\n+DEPLOYMENT_STATUS_TRIGGER_UPSCALE_COMPLETED\x10\x03\x12\x31\n-DEPLOYMENT_STATUS_TRIGGER_DOWNSCALE_COMPLETED\x10\x04\x12)\n%DEPLOYMENT_STATUS_TRIGGER_AUTOSCALING\x10\x05\x12\x34\n0DEPLOYMENT_STATUS_TRIGGER_REPLICA_STARTUP_FAILED\x10\x06\x12\x31\n-DEPLOYMENT_STATUS_TRIGGER_HEALTH_CHECK_FAILED\x10\x07\x12,\n(DEPLOYMENT_STATUS_TRIGGER_INTERNAL_ERROR\x10\x08\x12&\n\"DEPLOYMENT_STATUS_TRIGGER_DELETING\x10\t*\xe2\x01\n\x11\x41pplicationStatus\x12 \n\x1c\x41PPLICATION_STATUS_DEPLOYING\x10\x00\x12\x1e\n\x1a\x41PPLICATION_STATUS_RUNNING\x10\x01\x12$\n APPLICATION_STATUS_DEPLOY_FAILED\x10\x02\x12\x1f\n\x1b\x41PPLICATION_STATUS_DELETING\x10\x03\x12\"\n\x1e\x41PPLICATION_STATUS_NOT_STARTED\x10\x05\x12 \n\x1c\x41PPLICATION_STATUS_UNHEALTHY\x10\x06\x32\xb3\x01\n\x12RayServeAPIService\x12[\n\x10ListApplications\x12\".ray.serve.ListApplicationsRequest\x1a#.ray.serve.ListApplicationsResponse\x12@\n\x07Healthz\x12\x19.ray.serve.HealthzRequest\x1a\x1a.ray.serve.HealthzResponse2\xc3\x02\n\x12UserDefinedService\x12I\n\x08__call__\x12\x1d.ray.serve.UserDefinedMessage\x1a\x1e.ray.serve.UserDefinedResponse\x12H\n\x07Method1\x12\x1d.ray.serve.UserDefinedMessage\x1a\x1e.ray.serve.UserDefinedResponse\x12J\n\x07Method2\x12\x1e.ray.serve.UserDefinedMessage2\x1a\x1f.ray.serve.UserDefinedResponse2\x12L\n\tStreaming\x12\x1d.ray.serve.UserDefinedMessage\x1a\x1e.ray.serve.UserDefinedResponse0\x01\x32L\n\x0c\x46ruitService\x12<\n\nFruitStand\x12\x17.ray.serve.FruitAmounts\x1a\x15.ray.serve.FruitCosts2\x98\x01\n\x18RayServeBenchmarkService\x12\x39\n\tgrpc_call\x12\x14.ray.serve.ArrayData\x1a\x16.ray.serve.ModelOutput\x12\x41\n\x10\x63\x61ll_with_string\x12\x15.ray.serve.StringData\x1a\x16.ray.serve.ModelOutputB\x8d\x01\n\rcom.ray.serveB\nServeProtoP\x01Z+github.com/instill-ai/protogen-go/model/ray\xa2\x02\x03RSX\xaa\x02\tRay.Serve\xca\x02\tRay\\Serve\xe2\x02\x15Ray\\Serve\\GPBMetadata\xea\x02\nRay::Serveb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'model.ray.serve_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\rcom.ray.serveB\nServeProtoP\001Z+github.com/instill-ai/protogen-go/model/ray\242\002\003RSX\252\002\tRay.Serve\312\002\tRay\\Serve\342\002\025Ray\\Serve\\GPBMetadata\352\002\nRay::Serve'
  _REQUESTMETADATA_CONTEXTENTRY._options = None
  _REQUESTMETADATA_CONTEXTENTRY._serialized_options = b'8\001'
  _LONGPOLLREQUEST_KEYSTOSNAPSHOTIDSENTRY._options = None
  _LONGPOLLREQUEST_KEYSTOSNAPSHOTIDSENTRY._serialized_options = b'8\001'
  _LONGPOLLRESULT_UPDATEDOBJECTSENTRY._options = None
  _LONGPOLLRESULT_UPDATEDOBJECTSENTRY._serialized_options = b'8\001'
  _ENDPOINTINFO_CONFIGENTRY._options = None
  _ENDPOINTINFO_CONFIGENTRY._serialized_options = b'8\001'
  _ENDPOINTSET_ENDPOINTSENTRY._options = None
  _ENDPOINTSET_ENDPOINTSENTRY._serialized_options = b'8\001'
  _globals['_ENCODINGTYPE']._serialized_start=6208
  _globals['_ENCODINGTYPE']._serialized_end=6242
  _globals['_DEPLOYMENTLANGUAGE']._serialized_start=6244
  _globals['_DEPLOYMENTLANGUAGE']._serialized_end=6286
  _globals['_TARGETCAPACITYDIRECTION']._serialized_start=6288
  _globals['_TARGETCAPACITYDIRECTION']._serialized_end=6342
  _globals['_DEPLOYMENTSTATUS']._serialized_start=6345
  _globals['_DEPLOYMENTSTATUS']._serialized_end=6564
  _globals['_DEPLOYMENTSTATUSTRIGGER']._serialized_start=6567
  _globals['_DEPLOYMENTSTATUSTRIGGER']._serialized_end=7077
  _globals['_APPLICATIONSTATUS']._serialized_start=7080
  _globals['_APPLICATIONSTATUS']._serialized_end=7306
  _globals['_AUTOSCALINGCONFIG']._serialized_start=37
  _globals['_AUTOSCALINGCONFIG']._serialized_end=881
  _globals['_LOGGINGCONFIG']._serialized_start=884
  _globals['_LOGGINGCONFIG']._serialized_end=1119
  _globals['_DEPLOYMENTCONFIG']._serialized_start=1122
  _globals['_DEPLOYMENTCONFIG']._serialized_end=1896
  _globals['_REQUESTMETADATA']._serialized_start=1899
  _globals['_REQUESTMETADATA']._serialized_end=2227
  _globals['_REQUESTMETADATA_CONTEXTENTRY']._serialized_start=2169
  _globals['_REQUESTMETADATA_CONTEXTENTRY']._serialized_end=2227
  _globals['_REQUESTWRAPPER']._serialized_start=2229
  _globals['_REQUESTWRAPPER']._serialized_end=2265
  _globals['_UPDATEDOBJECT']._serialized_start=2267
  _globals['_UPDATEDOBJECT']._serialized_end=2356
  _globals['_LONGPOLLREQUEST']._serialized_start=2359
  _globals['_LONGPOLLREQUEST']._serialized_end=2546
  _globals['_LONGPOLLREQUEST_KEYSTOSNAPSHOTIDSENTRY']._serialized_start=2478
  _globals['_LONGPOLLREQUEST_KEYSTOSNAPSHOTIDSENTRY']._serialized_end=2546
  _globals['_LONGPOLLRESULT']._serialized_start=2549
  _globals['_LONGPOLLRESULT']._serialized_end=2746
  _globals['_LONGPOLLRESULT_UPDATEDOBJECTSENTRY']._serialized_start=2655
  _globals['_LONGPOLLRESULT_UPDATEDOBJECTSENTRY']._serialized_end=2746
  _globals['_ENDPOINTINFO']._serialized_start=2749
  _globals['_ENDPOINTINFO']._serialized_end=2942
  _globals['_ENDPOINTINFO_CONFIGENTRY']._serialized_start=2885
  _globals['_ENDPOINTINFO_CONFIGENTRY']._serialized_end=2942
  _globals['_ENDPOINTSET']._serialized_start=2945
  _globals['_ENDPOINTSET']._serialized_end=3114
  _globals['_ENDPOINTSET_ENDPOINTSENTRY']._serialized_start=3029
  _globals['_ENDPOINTSET_ENDPOINTSENTRY']._serialized_end=3114
  _globals['_ACTORNAMELIST']._serialized_start=3116
  _globals['_ACTORNAMELIST']._serialized_end=3153
  _globals['_DEPLOYMENTTARGETINFO']._serialized_start=3155
  _globals['_DEPLOYMENTTARGETINFO']._serialized_end=3249
  _globals['_DEPLOYMENTVERSION']._serialized_start=3252
  _globals['_DEPLOYMENTVERSION']._serialized_end=3589
  _globals['_REPLICACONFIG']._serialized_start=3592
  _globals['_REPLICACONFIG']._serialized_end=3965
  _globals['_DEPLOYMENTINFO']._serialized_start=3968
  _globals['_DEPLOYMENTINFO']._serialized_end=4405
  _globals['_DEPLOYMENTROUTE']._serialized_start=4407
  _globals['_DEPLOYMENTROUTE']._serialized_end=4514
  _globals['_DEPLOYMENTROUTELIST']._serialized_start=4516
  _globals['_DEPLOYMENTROUTELIST']._serialized_end=4610
  _globals['_DEPLOYMENTSTATUSINFO']._serialized_start=4613
  _globals['_DEPLOYMENTSTATUSINFO']._serialized_end=4809
  _globals['_DEPLOYMENTSTATUSINFOLIST']._serialized_start=4811
  _globals['_DEPLOYMENTSTATUSINFOLIST']._serialized_end=4926
  _globals['_APPLICATIONSTATUSINFO']._serialized_start=4929
  _globals['_APPLICATIONSTATUSINFO']._serialized_end=5083
  _globals['_STATUSOVERVIEW']._serialized_start=5086
  _globals['_STATUSOVERVIEW']._serialized_end=5273
  _globals['_LISTAPPLICATIONSREQUEST']._serialized_start=5275
  _globals['_LISTAPPLICATIONSREQUEST']._serialized_end=5300
  _globals['_LISTAPPLICATIONSRESPONSE']._serialized_start=5302
  _globals['_LISTAPPLICATIONSRESPONSE']._serialized_end=5373
  _globals['_HEALTHZREQUEST']._serialized_start=5375
  _globals['_HEALTHZREQUEST']._serialized_end=5391
  _globals['_HEALTHZRESPONSE']._serialized_start=5393
  _globals['_HEALTHZRESPONSE']._serialized_end=5436
  _globals['_USERDEFINEDMESSAGE']._serialized_start=5438
  _globals['_USERDEFINEDMESSAGE']._serialized_end=5514
  _globals['_USERDEFINEDRESPONSE']._serialized_start=5516
  _globals['_USERDEFINEDRESPONSE']._serialized_end=5588
  _globals['_USERDEFINEDMESSAGE2']._serialized_start=5590
  _globals['_USERDEFINEDMESSAGE2']._serialized_end=5611
  _globals['_USERDEFINEDRESPONSE2']._serialized_start=5613
  _globals['_USERDEFINEDRESPONSE2']._serialized_end=5663
  _globals['_FRUITAMOUNTS']._serialized_start=5665
  _globals['_FRUITAMOUNTS']._serialized_end=5749
  _globals['_FRUITCOSTS']._serialized_start=5751
  _globals['_FRUITCOSTS']._serialized_end=5785
  _globals['_ARRAYDATA']._serialized_start=5787
  _globals['_ARRAYDATA']._serialized_end=5818
  _globals['_STRINGDATA']._serialized_start=5820
  _globals['_STRINGDATA']._serialized_end=5852
  _globals['_MODELOUTPUT']._serialized_start=5854
  _globals['_MODELOUTPUT']._serialized_end=5891
  _globals['_DEPLOYMENTARGS']._serialized_start=5894
  _globals['_DEPLOYMENTARGS']._serialized_end=6206
  _globals['_RAYSERVEAPISERVICE']._serialized_start=7309
  _globals['_RAYSERVEAPISERVICE']._serialized_end=7488
  _globals['_USERDEFINEDSERVICE']._serialized_start=7491
  _globals['_USERDEFINEDSERVICE']._serialized_end=7814
  _globals['_FRUITSERVICE']._serialized_start=7816
  _globals['_FRUITSERVICE']._serialized_end=7892
  _globals['_RAYSERVEBENCHMARKSERVICE']._serialized_start=7895
  _globals['_RAYSERVEBENCHMARKSERVICE']._serialized_end=8047
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.struct_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class CallRequest(google.protobuf.message.Message):
    """CallRequest represents a request for model inference"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_INPUTS_FIELD_NUMBER: builtins.int
    @property
    def task_inputs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[google.protobuf.struct_pb2.Struct]:
        """Inference input parameters."""
    def __init__(
        self,
        *,
        task_inputs: collections.abc.Iterable[google.protobuf.struct_pb2.Struct] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["task_inputs", b"task_inputs"]) -> None: ...

global___CallRequest = CallRequest

@typing_extensions.final
class CallResponse(google.protobuf.message.Message):
    """CallResponse represents a response for model inference"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_OUTPUTS_FIELD_NUMBER: builtins.int
    @property
    def task_outputs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[google.protobuf.struct_pb2.Struct]:
        """Model inference outputs."""
    def __init__(
        self,
        *,
        task_outputs: collections.abc.Iterable[google.protobuf.struct_pb2.Struct] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["task_outputs", b"task_outputs"]) -> None: ...

global___CallResponse = CallResponse



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: agent/agent/v1alpha/chat.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from agent.agent.v1alpha import common_pb2 as agent_dot_agent_dot_v1alpha_dot_common__pb2
from agent.agent.v1alpha import table_pb2 as agent_dot_agent_dot_v1alpha_dot_table__pb2
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1e\x61gent/agent/v1alpha/chat.proto\x12\x13\x61gent.agent.v1alpha\x1a agent/agent/v1alpha/common.proto\x1a\x1f\x61gent/agent/v1alpha/table.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xd0\x01\n\x0b\x41gentConfig\x12\'\n\x0cinstructions\x18\x01 \x01(\tB\x03\xe0\x41\x01R\x0cinstructions\x12X\n\x0b\x63onnections\x18\x02 \x03(\x0b\x32\x31.agent.agent.v1alpha.AgentConfig.ConnectionsEntryB\x03\xe0\x41\x01R\x0b\x63onnections\x1a>\n\x10\x43onnectionsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\"\xac\x03\n\x04\x43hat\x12\x15\n\x03uid\x18\x01 \x01(\tB\x03\xe0\x41\x03R\x03uid\x12&\n\x0cnamespace_id\x18\x02 \x01(\tB\x03\xe0\x41\x02R\x0bnamespaceId\x12/\n\x11\x63hat_display_name\x18\x03 \x01(\tB\x03\xe0\x41\x01R\x0f\x63hatDisplayName\x12H\n\x0c\x61gent_config\x18\x04 \x01(\x0b\x32 .agent.agent.v1alpha.AgentConfigB\x03\xe0\x41\x03R\x0b\x61gentConfig\x12@\n\x0b\x63reate_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03R\ncreateTime\x12@\n\x0bupdate_time\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03R\nupdateTime\x12@\n\x0b\x64\x65lete_time\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03R\ndeleteTime\x12$\n\ncatalog_id\x18\x08 \x01(\tB\x05\x18\x01\xe0\x41\x03R\tcatalogId\"\xaf\x05\n\x07Message\x12\x15\n\x03uid\x18\x01 \x01(\tB\x03\xe0\x41\x03R\x03uid\x12\x1e\n\x08\x63hat_uid\x18\x02 \x01(\tB\x03\xe0\x41\x03R\x07\x63hatUid\x12\x1d\n\x07\x63ontent\x18\x03 \x01(\tB\x03\xe0\x41\x02R\x07\x63ontent\x12\x17\n\x04role\x18\x04 \x01(\tB\x03\xe0\x41\x02R\x04role\x12\x41\n\x04type\x18\x05 \x01(\x0e\x32(.agent.agent.v1alpha.Message.MessageTypeB\x03\xe0\x41\x02R\x04type\x12@\n\x0b\x63reate_time\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03R\ncreateTime\x12@\n\x0bupdate_time\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03R\nupdateTime\x12)\n\x0emsg_sender_uid\x18\x08 \x01(\tB\x03\xe0\x41\x03R\x0cmsgSenderUid\x12@\n\tcitations\x18\t \x03(\x0b\x32\x1d.agent.agent.v1alpha.CitationB\x03\xe0\x41\x03R\tcitations\x12?\n\x07\x63ontext\x18\n \x01(\x0b\x32 .agent.agent.v1alpha.ChatContextB\x03\xe0\x41\x03R\x07\x63ontext\x12K\n\x0b\x61ttachments\x18\x0b \x01(\x0b\x32$.agent.agent.v1alpha.ChatAttachmentsB\x03\xe0\x41\x03R\x0b\x61ttachments\x12/\n\x11\x65nable_web_search\x18\x0c \x01(\x08\x42\x03\xe0\x41\x03R\x0f\x65nableWebSearch\"B\n\x0bMessageType\x12\x1c\n\x18MESSAGE_TYPE_UNSPECIFIED\x10\x00\x12\x15\n\x11MESSAGE_TYPE_TEXT\x10\x01\"1\n\x0b\x43hatContext\x12\"\n\ntable_uids\x18\x01 \x03(\tB\x03\xe0\x41\x01R\ttableUids\"3\n\x0f\x43hatAttachments\x12 \n\tfile_urls\x18\x01 \x03(\tB\x03\xe0\x41\x03R\x08\x66ileUrls\"\xdc\x01\n\x11\x43reateChatRequest\x12&\n\x0cnamespace_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x0bnamespaceId\x12/\n\x11\x63hat_display_name\x18\x02 \x01(\tB\x03\xe0\x41\x01R\x0f\x63hatDisplayName\x12H\n\x0c\x61gent_config\x18\x03 \x01(\x0b\x32 .agent.agent.v1alpha.AgentConfigB\x03\xe0\x41\x01R\x0b\x61gentConfig\x12$\n\ncatalog_id\x18\x04 \x01(\tB\x05\x18\x01\xe0\x41\x01R\tcatalogId\"H\n\x12\x43reateChatResponse\x12\x32\n\x04\x63hat\x18\x01 \x01(\x0b\x32\x19.agent.agent.v1alpha.ChatB\x03\xe0\x41\x03R\x04\x63hat\"\xbc\x01\n\x10ListChatsRequest\x12&\n\x0cnamespace_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x0bnamespaceId\x12 \n\tpage_size\x18\x02 \x01(\x05\x42\x03\xe0\x41\x01R\x08pageSize\x12\"\n\npage_token\x18\x03 \x01(\tB\x03\xe0\x41\x01R\tpageToken\x12\x1a\n\x06if_all\x18\x04 \x01(\x08\x42\x03\xe0\x41\x01R\x05ifAll\x12\x1e\n\x08\x63hat_uid\x18\x05 \x01(\tB\x03\xe0\x41\x01R\x07\x63hatUid\"\x9a\x01\n\x11ListChatsResponse\x12\x34\n\x05\x63hats\x18\x01 \x03(\x0b\x32\x19.agent.agent.v1alpha.ChatB\x03\xe0\x41\x03R\x05\x63hats\x12+\n\x0fnext_page_token\x18\x02 \x01(\tB\x03\xe0\x41\x03R\rnextPageToken\x12\"\n\ntotal_size\x18\x03 \x01(\x05\x42\x03\xe0\x41\x03R\ttotalSize\"\xd1\x01\n\x11UpdateChatRequest\x12!\n\x0cnamespace_id\x18\x01 \x01(\tR\x0bnamespaceId\x12\x1e\n\x08\x63hat_uid\x18\x02 \x01(\tB\x03\xe0\x41\x02R\x07\x63hatUid\x12/\n\x11\x63hat_display_name\x18\x03 \x01(\tB\x03\xe0\x41\x01R\x0f\x63hatDisplayName\x12H\n\x0c\x61gent_config\x18\x04 \x01(\x0b\x32 .agent.agent.v1alpha.AgentConfigB\x03\xe0\x41\x01R\x0b\x61gentConfig\"H\n\x12UpdateChatResponse\x12\x32\n\x04\x63hat\x18\x01 \x01(\x0b\x32\x19.agent.agent.v1alpha.ChatB\x03\xe0\x41\x03R\x04\x63hat\"X\n\x0eGetChatRequest\x12&\n\x0cnamespace_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x0bnamespaceId\x12\x1e\n\x08\x63hat_uid\x18\x02 \x01(\tB\x03\xe0\x41\x02R\x07\x63hatUid\"E\n\x0fGetChatResponse\x12\x32\n\x04\x63hat\x18\x01 \x01(\x0b\x32\x19.agent.agent.v1alpha.ChatB\x03\xe0\x41\x03R\x04\x63hat\"[\n\x11\x44\x65leteChatRequest\x12&\n\x0cnamespace_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x0bnamespaceId\x12\x1e\n\x08\x63hat_uid\x18\x02 \x01(\tB\x03\xe0\x41\x02R\x07\x63hatUid\"\x14\n\x12\x44\x65leteChatResponse\"\xd5\x01\n\x14MessageSenderProfile\x12)\n\x0emsg_sender_uid\x18\x01 \x01(\tB\x03\xe0\x41\x03R\x0cmsgSenderUid\x12\'\n\rmsg_sender_id\x18\x02 \x01(\tB\x03\xe0\x41\x03R\x0bmsgSenderId\x12+\n\x0c\x64isplay_name\x18\x03 \x01(\tB\x03\xe0\x41\x03H\x00R\x0b\x64isplayName\x88\x01\x01\x12 \n\x06\x61vatar\x18\x04 \x01(\tB\x03\xe0\x41\x03H\x01R\x06\x61vatar\x88\x01\x01\x42\x0f\n\r_display_nameB\t\n\x07_avatar\"\xbf\x01\n\x13ListMessagesRequest\x12&\n\x0cnamespace_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x0bnamespaceId\x12\x1e\n\x08\x63hat_uid\x18\x02 \x01(\tB\x03\xe0\x41\x02R\x07\x63hatUid\x12 \n\tpage_size\x18\x03 \x01(\x05\x42\x03\xe0\x41\x03R\x08pageSize\x12\"\n\npage_token\x18\x04 \x01(\tB\x03\xe0\x41\x03R\tpageToken\x12\x1a\n\x06if_all\x18\x05 \x01(\x08\x42\x03\xe0\x41\x01R\x05ifAll\"\xff\x01\n\x14ListMessagesResponse\x12=\n\x08messages\x18\x01 \x03(\x0b\x32\x1c.agent.agent.v1alpha.MessageB\x03\xe0\x41\x03R\x08messages\x12+\n\x0fnext_page_token\x18\x02 \x01(\tB\x03\xe0\x41\x03R\rnextPageToken\x12\"\n\ntotal_size\x18\x03 \x01(\x05\x42\x03\xe0\x41\x03R\ttotalSize\x12W\n\x0fsender_profiles\x18\x04 \x03(\x0b\x32).agent.agent.v1alpha.MessageSenderProfileB\x03\xe0\x41\x03R\x0esenderProfiles\"\xb9\x02\n\x14\x43hatWithAgentRequest\x12&\n\x0cnamespace_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x0bnamespaceId\x12\x1e\n\x08\x63hat_uid\x18\x02 \x01(\tB\x03\xe0\x41\x02R\x07\x63hatUid\x12\x1d\n\x07message\x18\x03 \x01(\tB\x03\xe0\x41\x02R\x07message\x12\"\n\tfile_uids\x18\x04 \x03(\tB\x05\x18\x01\xe0\x41\x01R\x08\x66ileUids\x12/\n\x11\x65nable_web_search\x18\x05 \x01(\x08\x42\x03\xe0\x41\x01R\x0f\x65nableWebSearch\x12$\n\x0bobject_uids\x18\x06 \x03(\tB\x03\xe0\x41\x01R\nobjectUids\x12?\n\x07\x63ontext\x18\x07 \x01(\x0b\x32 .agent.agent.v1alpha.ChatContextB\x03\xe0\x41\x01R\x07\x63ontext\"O\n\x15\x43hatWithAgentResponse\x12\x36\n\x07outputs\x18\x01 \x03(\x0b\x32\x17.google.protobuf.StructB\x03\xe0\x41\x03R\x07outputs\"9\n\x18TableBuilderAgentMessage\x12\x1d\n\x07message\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x07message\"\xd2\x01\n$ListTableBuilderAgentMessagesRequest\x12&\n\x0cnamespace_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x0bnamespaceId\x12 \n\ttable_uid\x18\x02 \x01(\tB\x03\xe0\x41\x02R\x08tableUid\x12 \n\tpage_size\x18\x03 \x01(\x05\x42\x03\xe0\x41\x03R\x08pageSize\x12\"\n\npage_token\x18\x04 \x01(\tB\x03\xe0\x41\x03R\tpageToken\x12\x1a\n\x06if_all\x18\x05 \x01(\x08\x42\x03\xe0\x41\x01R\x05ifAll\"\x90\x02\n%ListTableBuilderAgentMessagesResponse\x12=\n\x08messages\x18\x01 \x03(\x0b\x32\x1c.agent.agent.v1alpha.MessageB\x03\xe0\x41\x03R\x08messages\x12+\n\x0fnext_page_token\x18\x02 \x01(\tB\x03\xe0\x41\x03R\rnextPageToken\x12\"\n\ntotal_size\x18\x03 \x01(\x05\x42\x03\xe0\x41\x03R\ttotalSize\x12W\n\x0fsender_profiles\x18\x04 \x03(\x0b\x32).agent.agent.v1alpha.MessageSenderProfileB\x03\xe0\x41\x03R\x0esenderProfiles\"\x8b\x01\n ChatWithTableBuilderAgentRequest\x12&\n\x0cnamespace_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x0bnamespaceId\x12 \n\ttable_uid\x18\x02 \x01(\tB\x03\xe0\x41\x02R\x08tableUid\x12\x1d\n\x07message\x18\x03 \x01(\tB\x03\xe0\x41\x02R\x07message\"^\n!ChatWithTableBuilderAgentResponse\x12\x39\n\x05\x65vent\x18\x01 \x01(\x0b\x32\x1e.agent.agent.v1alpha.ChatEventB\x03\xe0\x41\x03R\x05\x65vent\"\xa5\x0b\n\tChatEvent\x12\x19\n\x05\x65vent\x18\x01 \x01(\tB\x03\xe0\x41\x03R\x05\x65vent\x12\x13\n\x02id\x18\x02 \x01(\tB\x03\xe0\x41\x03R\x02id\x12U\n\x12\x63hat_started_event\x18\x03 \x01(\x0b\x32%.agent.agent.v1alpha.ChatStartedEventH\x00R\x10\x63hatStartedEvent\x12h\n\x19\x63hat_status_updated_event\x18\x04 \x01(\x0b\x32+.agent.agent.v1alpha.ChatStatusUpdatedEventH\x00R\x16\x63hatStatusUpdatedEvent\x12h\n\x19\x63hat_output_updated_event\x18\x05 \x01(\x0b\x32+.agent.agent.v1alpha.ChatOutputUpdatedEventH\x00R\x16\x63hatOutputUpdatedEvent\x12\x62\n\x17\x63hat_name_updated_event\x18\x06 \x01(\x0b\x32).agent.agent.v1alpha.ChatNameUpdatedEventH\x00R\x14\x63hatNameUpdatedEvent\x12n\n\x1b\x63hat_replan_triggered_event\x18\x07 \x01(\x0b\x32-.agent.agent.v1alpha.ChatReplanTriggeredEventH\x00R\x18\x63hatReplanTriggeredEvent\x12{\n chat_citation_list_updated_event\x18\x08 \x01(\x0b\x32\x31.agent.agent.v1alpha.ChatCitationListUpdatedEventH\x00R\x1c\x63hatCitationListUpdatedEvent\x12\x65\n\x18\x63hat_table_created_event\x18\t \x01(\x0b\x32*.agent.agent.v1alpha.ChatTableCreatedEventH\x00R\x15\x63hatTableCreatedEvent\x12\x65\n\x18\x63hat_error_updated_event\x18\n \x01(\x0b\x32*.agent.agent.v1alpha.ChatErrorUpdatedEventH\x00R\x15\x63hatErrorUpdatedEvent\x12x\n\x1f\x63hat_debug_output_updated_event\x18\x0b \x01(\x0b\x32\x30.agent.agent.v1alpha.ChatDebugOutputUpdatedEventH\x00R\x1b\x63hatDebugOutputUpdatedEvent\x12O\n\x10\x63hat_ended_event\x18\x0c \x01(\x0b\x32#.agent.agent.v1alpha.ChatEndedEventH\x00R\x0e\x63hatEndedEvent\x12w\n\x1e\x63hat_attachments_updated_event\x18\r \x01(\x0b\x32\x30.agent.agent.v1alpha.ChatAttachmentsUpdatedEventH\x00R\x1b\x63hatAttachmentsUpdatedEvent\x12k\n\x1a\x63hat_context_updated_event\x18\x0e \x01(\x0b\x32,.agent.agent.v1alpha.ChatContextUpdatedEventH\x00R\x17\x63hatContextUpdatedEvent\x12\x65\n\x18\x63hat_table_updated_event\x18\x0f \x01(\x0b\x32*.agent.agent.v1alpha.ChatTableUpdatedEventH\x00R\x15\x63hatTableUpdatedEventB\x06\n\x04\x64\x61ta\"T\n\x10\x43hatStartedEvent\x12@\n\x0b\x63reate_time\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03R\ncreateTime\"\x80\x01\n\x16\x43hatStatusUpdatedEvent\x12@\n\x0b\x63reate_time\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03R\ncreateTime\x12$\n\x0b\x63hat_status\x18\x02 \x01(\tB\x03\xe0\x41\x03R\nchatStatus\"\x90\x01\n\x16\x43hatOutputUpdatedEvent\x12@\n\x0b\x63reate_time\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03R\ncreateTime\x12\x34\n\x12output_chunk_delta\x18\x02 \x01(\tB\x06\xe0\x41\x03\xe0\x41\x02R\x10outputChunkDelta\"q\n\x14\x43hatNameUpdatedEvent\x12@\n\x0b\x63reate_time\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03R\ncreateTime\x12\x17\n\x04name\x18\x02 \x01(\tB\x03\xe0\x41\x03R\x04name\"\x8b\x01\n\x18\x43hatReplanTriggeredEvent\x12@\n\x0b\x63reate_time\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03R\ncreateTime\x12-\n\x10number_of_replan\x18\x02 \x01(\rB\x03\xe0\x41\x03R\x0enumberOfReplan\"\xa5\x01\n\x1c\x43hatCitationListUpdatedEvent\x12@\n\x0b\x63reate_time\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03R\ncreateTime\x12\x43\n\tcitations\x18\x02 \x03(\x0b\x32\x1d.agent.agent.v1alpha.CitationB\x06\xe0\x41\x03\xe0\x41\x02R\tcitations\"\xac\x01\n\x1b\x43hatAttachmentsUpdatedEvent\x12@\n\x0b\x63reate_time\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03R\ncreateTime\x12K\n\x0b\x61ttachments\x18\x02 \x01(\x0b\x32$.agent.agent.v1alpha.ChatAttachmentsB\x03\xe0\x41\x03R\x0b\x61ttachments\"\x9c\x01\n\x17\x43hatContextUpdatedEvent\x12@\n\x0b\x63reate_time\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03R\ncreateTime\x12?\n\x07\x63ontext\x18\x02 \x01(\x0b\x32 .agent.agent.v1alpha.ChatContextB\x03\xe0\x41\x03R\x07\x63ontext\"\x96\x03\n\x15\x43hatTableCreatedEvent\x12@\n\x0b\x63reate_time\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03R\ncreateTime\x12 \n\ttable_uid\x18\x02 \x01(\tB\x03\xe0\x41\x03R\x08tableUid\x12\x35\n\x05table\x18\x03 \x01(\x0b\x32\x1a.agent.agent.v1alpha.TableB\x03\xe0\x41\x03R\x05table\x12u\n\x12\x63olumn_definitions\x18\x04 \x03(\x0b\x32\x41.agent.agent.v1alpha.ChatTableCreatedEvent.ColumnDefinitionsEntryB\x03\xe0\x41\x03R\x11\x63olumnDefinitions\x1ak\n\x16\x43olumnDefinitionsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12;\n\x05value\x18\x02 \x01(\x0b\x32%.agent.agent.v1alpha.ColumnDefinitionR\x05value:\x02\x38\x01\"\x96\x03\n\x15\x43hatTableUpdatedEvent\x12@\n\x0b\x63reate_time\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03R\ncreateTime\x12 \n\ttable_uid\x18\x02 \x01(\tB\x03\xe0\x41\x03R\x08tableUid\x12\x35\n\x05table\x18\x03 \x01(\x0b\x32\x1a.agent.agent.v1alpha.TableB\x03\xe0\x41\x03R\x05table\x12u\n\x12\x63olumn_definitions\x18\x04 \x03(\x0b\x32\x41.agent.agent.v1alpha.ChatTableUpdatedEvent.ColumnDefinitionsEntryB\x03\xe0\x41\x03R\x11\x63olumnDefinitions\x1ak\n\x16\x43olumnDefinitionsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12;\n\x05value\x18\x02 \x01(\x0b\x32%.agent.agent.v1alpha.ColumnDefinitionR\x05value:\x02\x38\x01\"\x98\x01\n\x15\x43hatErrorUpdatedEvent\x12@\n\x0b\x63reate_time\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03R\ncreateTime\x12\"\n\nerror_type\x18\x02 \x01(\tB\x03\xe0\x41\x03R\terrorType\x12\x19\n\x05\x65rror\x18\x03 \x01(\tB\x03\xe0\x41\x03R\x05\x65rror\"\x87\x01\n\x1b\x43hatDebugOutputUpdatedEvent\x12@\n\x0b\x63reate_time\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03R\ncreateTime\x12&\n\x0c\x64\x65\x62ug_output\x18\x02 \x01(\tB\x03\xe0\x41\x03R\x0b\x64\x65\x62ugOutput\"R\n\x0e\x43hatEndedEvent\x12@\n\x0b\x63reate_time\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03R\ncreateTimeB\xd6\x01\n\x17\x63om.agent.agent.v1alphaB\tChatProtoP\x01ZBgithub.com/instill-ai/protogen-go/agent/agent/v1alpha;agentv1alpha\xa2\x02\x03\x41\x41X\xaa\x02\x13\x41gent.Agent.V1alpha\xca\x02\x13\x41gent\\Agent\\V1alpha\xe2\x02\x1f\x41gent\\Agent\\V1alpha\\GPBMetadata\xea\x02\x15\x41gent::Agent::V1alphab\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'agent.agent.v1alpha.chat_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\027com.agent.agent.v1alphaB\tChatProtoP\001ZBgithub.com/instill-ai/protogen-go/agent/agent/v1alpha;agentv1alpha\242\002\003AAX\252\002\023Agent.Agent.V1alpha\312\002\023Agent\\Agent\\V1alpha\342\002\037Agent\\Agent\\V1alpha\\GPBMetadata\352\002\025Agent::Agent::V1alpha'
  _AGENTCONFIG_CONNECTIONSENTRY._options = None
  _AGENTCONFIG_CONNECTIONSENTRY._serialized_options = b'8\001'
  _AGENTCONFIG.fields_by_name['instructions']._options = None
  _AGENTCONFIG.fields_by_name['instructions']._serialized_options = b'\340A\001'
  _AGENTCONFIG.fields_by_name['connections']._options = None
  _AGENTCONFIG.fields_by_name['connections']._serialized_options = b'\340A\001'
  _CHAT.fields_by_name['uid']._options = None
  _CHAT.fields_by_name['uid']._serialized_options = b'\340A\003'
  _CHAT.fields_by_name['namespace_id']._options = None
  _CHAT.fields_by_name['namespace_id']._serialized_options = b'\340A\002'
  _CHAT.fields_by_name['chat_display_name']._options = None
  _CHAT.fields_by_name['chat_display_name']._serialized_options = b'\340A\001'
  _CHAT.fields_by_name['agent_config']._options = None
  _CHAT.fields_by_name['agent_config']._serialized_options = b'\340A\003'
  _CHAT.fields_by_name['create_time']._options = None
  _CHAT.fields_by_name['create_time']._serialized_options = b'\340A\003'
  _CHAT.fields_by_name['update_time']._options = None
  _CHAT.fields_by_name['update_time']._serialized_options = b'\340A\003'
  _CHAT.fields_by_name['delete_time']._options = None
  _CHAT.fields_by_name['delete_time']._serialized_options = b'\340A\003'
  _CHAT.fields_by_name['catalog_id']._options = None
  _CHAT.fields_by_name['catalog_id']._serialized_options = b'\030\001\340A\003'
  _MESSAGE.fields_by_name['uid']._options = None
  _MESSAGE.fields_by_name['uid']._serialized_options = b'\340A\003'
  _MESSAGE.fields_by_name['chat_uid']._options = None
  _MESSAGE.fields_by_name['chat_uid']._serialized_options = b'\340A\003'
  _MESSAGE.fields_by_name['content']._options = None
  _MESSAGE.fields_by_name['content']._serialized_options = b'\340A\002'
  _MESSAGE.fields_by_name['role']._options = None
  _MESSAGE.fields_by_name['role']._serialized_options = b'\340A\002'
  _MESSAGE.fields_by_name['type']._options = None
  _MESSAGE.fields_by_name['type']._serialized_options = b'\340A\002'
  _MESSAGE.fields_by_name['create_time']._options = None
  _MESSAGE.fields_by_name['create_time']._serialized_options = b'\340A\003'
  _MESSAGE.fields_by_name['update_time']._options = None
  _MESSAGE.fields_by_name['update_time']._serialized_options = b'\340A\003'
  _MESSAGE.fields_by_name['msg_sender_uid']._options = None
  _MESSAGE.fields_by_name['msg_sender_uid']._serialized_options = b'\340A\003'
  _MESSAGE.fields_by_name['citations']._options = None
  _MESSAGE.fields_by_name['citations']._serialized_options = b'\340A\003'
  _MESSAGE.fields_by_name['context']._options = None
  _MESSAGE.fields_by_name['context']._serialized_options = b'\340A\003'
  _MESSAGE.fields_by_name['attachments']._options = None
  _MESSAGE.fields_by_name['attachments']._serialized_options = b'\340A\003'
  _MESSAGE.fields_by_name['enable_web_search']._options = None
  _MESSAGE.fields_by_name['enable_web_search']._serialized_options = b'\340A\003'
  _CHATCONTEXT.fields_by_name['table_uids']._options = None
  _CHATCONTEXT.fields_by_name['table_uids']._serialized_options = b'\340A\001'
  _CHATATTACHMENTS.fields_by_name['file_urls']._options = None
  _CHATATTACHMENTS.fields_by_name['file_urls']._serialized_options = b'\340A\003'
  _CREATECHATREQUEST.fields_by_name['namespace_id']._options = None
  _CREATECHATREQUEST.fields_by_name['namespace_id']._serialized_options = b'\340A\002'
  _CREATECHATREQUEST.fields_by_name['chat_display_name']._options = None
  _CREATECHATREQUEST.fields_by_name['chat_display_name']._serialized_options = b'\340A\001'
  _CREATECHATREQUEST.fields_by_name['agent_config']._options = None
  _CREATECHATREQUEST.fields_by_name['agent_config']._serialized_options = b'\340A\001'
  _CREATECHATREQUEST.fields_by_name['catalog_id']._options = None
  _CREATECHATREQUEST.fields_by_name['catalog_id']._serialized_options = b'\030\001\340A\001'
  _CREATECHATRESPONSE.fields_by_name['chat']._options = None
  _CREATECHATRESPONSE.fields_by_name['chat']._serialized_options = b'\340A\003'
  _LISTCHATSREQUEST.fields_by_name['namespace_id']._options = None
  _LISTCHATSREQUEST.fields_by_name['namespace_id']._serialized_options = b'\340A\002'
  _LISTCHATSREQUEST.fields_by_name['page_size']._options = None
  _LISTCHATSREQUEST.fields_by_name['page_size']._serialized_options = b'\340A\001'
  _LISTCHATSREQUEST.fields_by_name['page_token']._options = None
  _LISTCHATSREQUEST.fields_by_name['page_token']._serialized_options = b'\340A\001'
  _LISTCHATSREQUEST.fields_by_name['if_all']._options = None
  _LISTCHATSREQUEST.fields_by_name['if_all']._serialized_options = b'\340A\001'
  _LISTCHATSREQUEST.fields_by_name['chat_uid']._options = None
  _LISTCHATSREQUEST.fields_by_name['chat_uid']._serialized_options = b'\340A\001'
  _LISTCHATSRESPONSE.fields_by_name['chats']._options = None
  _LISTCHATSRESPONSE.fields_by_name['chats']._serialized_options = b'\340A\003'
  _LISTCHATSRESPONSE.fields_by_name['next_page_token']._options = None
  _LISTCHATSRESPONSE.fields_by_name['next_page_token']._serialized_options = b'\340A\003'
  _LISTCHATSRESPONSE.fields_by_name['total_size']._options = None
  _LISTCHATSRESPONSE.fields_by_name['total_size']._serialized_options = b'\340A\003'
  _UPDATECHATREQUEST.fields_by_name['chat_uid']._options = None
  _UPDATECHATREQUEST.fields_by_name['chat_uid']._serialized_options = b'\340A\002'
  _UPDATECHATREQUEST.fields_by_name['chat_display_name']._options = None
  _UPDATECHATREQUEST.fields_by_name['chat_display_name']._serialized_options = b'\340A\001'
  _UPDATECHATREQUEST.fields_by_name['agent_config']._options = None
  _UPDATECHATREQUEST.fields_by_name['agent_config']._serialized_options = b'\340A\001'
  _UPDATECHATRESPONSE.fields_by_name['chat']._options = None
  _UPDATECHATRESPONSE.fields_by_name['chat']._serialized_options = b'\340A\003'
  _GETCHATREQUEST.fields_by_name['namespace_id']._options = None
  _GETCHATREQUEST.fields_by_name['namespace_id']._serialized_options = b'\340A\002'
  _GETCHATREQUEST.fields_by_name['chat_uid']._options = None
  _GETCHATREQUEST.fields_by_name['chat_uid']._serialized_options = b'\340A\002'
  _GETCHATRESPONSE.fields_by_name['chat']._options = None
  _GETCHATRESPONSE.fields_by_name['chat']._serialized_options = b'\340A\003'
  _DELETECHATREQUEST.fields_by_name['namespace_id']._options = None
  _DELETECHATREQUEST.fields_by_name['namespace_id']._serialized_options = b'\340A\002'
  _DELETECHATREQUEST.fields_by_name['chat_uid']._options = None
  _DELETECHATREQUEST.fields_by_name['chat_uid']._serialized_options = b'\340A\002'
  _MESSAGESENDERPROFILE.fields_by_name['msg_sender_uid']._options = None
  _MESSAGESENDERPROFILE.fields_by_name['msg_sender_uid']._serialized_options = b'\340A\003'
  _MESSAGESENDERPROFILE.fields_by_name['msg_sender_id']._options = None
  _MESSAGESENDERPROFILE.fields_by_name['msg_sender_id']._serialized_options = b'\340A\003'
  _MESSAGESENDERPROFILE.fields_by_name['display_name']._options = None
  _MESSAGESENDERPROFILE.fields_by_name['display_name']._serialized_options = b'\340A\003'
  _MESSAGESENDERPROFILE.fields_by_name['avatar']._options = None
  _MESSAGESENDERPROFILE.fields_by_name['avatar']._serialized_options = b'\340A\003'
  _LISTMESSAGESREQUEST.fields_by_name['namespace_id']._options = None
  _LISTMESSAGESREQUEST.fields_by_name['namespace_id']._serialized_options = b'\340A\002'
  _LISTMESSAGESREQUEST.fields_by_name['chat_uid']._options = None
  _LISTMESSAGESREQUEST.fields_by_name['chat_uid']._serialized_options = b'\340A\002'
  _LISTMESSAGESREQUEST.fields_by_name['page_size']._options = None
  _LISTMESSAGESREQUEST.fields_by_name['page_size']._serialized_options = b'\340A\003'
  _LISTMESSAGESREQUEST.fields_by_name['page_token']._options = None
  _LISTMESSAGESREQUEST.fields_by_name['page_token']._serialized_options = b'\340A\003'
  _LISTMESSAGESREQUEST.fields_by_name['if_all']._options = None
  _LISTMESSAGESREQUEST.fields_by_name['if_all']._serialized_options = b'\340A\001'
  _LISTMESSAGESRESPONSE.fields_by_name['messages']._options = None
  _LISTMESSAGESRESPONSE.fields_by_name['messages']._serialized_options = b'\340A\003'
  _LISTMESSAGESRESPONSE.fields_by_name['next_page_token']._options = None
  _LISTMESSAGESRESPONSE.fields_by_name['next_page_token']._serialized_options = b'\340A\003'
  _LISTMESSAGESRESPONSE.fields_by_name['total_size']._options = None
  _LISTMESSAGESRESPONSE.fields_by_name['total_size']._serialized_options = b'\340A\003'
  _LISTMESSAGESRESPONSE.fields_by_name['sender_profiles']._options = None
  _LISTMESSAGESRESPONSE.fields_by_name['sender_profiles']._serialized_options = b'\340A\003'
  _CHATWITHAGENTREQUEST.fields_by_name['namespace_id']._options = None
  _CHATWITHAGENTREQUEST.fields_by_name['namespace_id']._serialized_options = b'\340A\002'
  _CHATWITHAGENTREQUEST.fields_by_name['chat_uid']._options = None
  _CHATWITHAGENTREQUEST.fields_by_name['chat_uid']._serialized_options = b'\340A\002'
  _CHATWITHAGENTREQUEST.fields_by_name['message']._options = None
  _CHATWITHAGENTREQUEST.fields_by_name['message']._serialized_options = b'\340A\002'
  _CHATWITHAGENTREQUEST.fields_by_name['file_uids']._options = None
  _CHATWITHAGENTREQUEST.fields_by_name['file_uids']._serialized_options = b'\030\001\340A\001'
  _CHATWITHAGENTREQUEST.fields_by_name['enable_web_search']._options = None
  _CHATWITHAGENTREQUEST.fields_by_name['enable_web_search']._serialized_options = b'\340A\001'
  _CHATWITHAGENTREQUEST.fields_by_name['object_uids']._options = None
  _CHATWITHAGENTREQUEST.fields_by_name['object_uids']._serialized_options = b'\340A\001'
  _CHATWITHAGENTREQUEST.fields_by_name['context']._options = None
  _CHATWITHAGENTREQUEST.fields_by_name['context']._serialized_options = b'\340A\001'
  _CHATWITHAGENTRESPONSE.fields_by_name['outputs']._options = None
  _CHATWITHAGENTRESPONSE.fields_by_name['outputs']._serialized_options = b'\340A\003'
  _TABLEBUILDERAGENTMESSAGE.fields_by_name['message']._options = None
  _TABLEBUILDERAGENTMESSAGE.fields_by_name['message']._serialized_options = b'\340A\002'
  _LISTTABLEBUILDERAGENTMESSAGESREQUEST.fields_by_name['namespace_id']._options = None
  _LISTTABLEBUILDERAGENTMESSAGESREQUEST.fields_by_name['namespace_id']._serialized_options = b'\340A\002'
  _LISTTABLEBUILDERAGENTMESSAGESREQUEST.fields_by_name['table_uid']._options = None
  _LISTTABLEBUILDERAGENTMESSAGESREQUEST.fields_by_name['table_uid']._serialized_options = b'\340A\002'
  _LISTTABLEBUILDERAGENTMESSAGESREQUEST.fields_by_name['page_size']._options = None
  _LISTTABLEBUILDERAGENTMESSAGESREQUEST.fields_by_name['page_size']._serialized_options = b'\340A\003'
  _LISTTABLEBUILDERAGENTMESSAGESREQUEST.fields_by_name['page_token']._options = None
  _LISTTABLEBUILDERAGENTMESSAGESREQUEST.fields_by_name['page_token']._serialized_options = b'\340A\003'
  _LISTTABLEBUILDERAGENTMESSAGESREQUEST.fields_by_name['if_all']._options = None
  _LISTTABLEBUILDERAGENTMESSAGESREQUEST.fields_by_name['if_all']._serialized_options = b'\340A\001'
  _LISTTABLEBUILDERAGENTMESSAGESRESPONSE.fields_by_name['messages']._options = None
  _LISTTABLEBUILDERAGENTMESSAGESRESPONSE.fields_by_name['messages']._serialized_options = b'\340A\003'
  _LISTTABLEBUILDERAGENTMESSAGESRESPONSE.fields_by_name['next_page_token']._options = None
  _LISTTABLEBUILDERAGENTMESSAGESRESPONSE.fields_by_name['next_page_token']._serialized_options = b'\340A\003'
  _LISTTABLEBUILDERAGENTMESSAGESRESPONSE.fields_by_name['total_size']._options = None
  _LISTTABLEBUILDERAGENTMESSAGESRESPONSE.fields_by_name['total_size']._serialized_options = b'\340A\003'
  _LISTTABLEBUILDERAGENTMESSAGESRESPONSE.fields_by_name['sender_profiles']._options = None
  _LISTTABLEBUILDERAGENTMESSAGESRESPONSE.fields_by_name['sender_profiles']._serialized_options = b'\340A\003'
  _CHATWITHTABLEBUILDERAGENTREQUEST.fields_by_name['namespace_id']._options = None
  _CHATWITHTABLEBUILDERAGENTREQUEST.fields_by_name['namespace_id']._serialized_options = b'\340A\002'
  _CHATWITHTABLEBUILDERAGENTREQUEST.fields_by_name['table_uid']._options = None
  _CHATWITHTABLEBUILDERAGENTREQUEST.fields_by_name['table_uid']._serialized_options = b'\340A\002'
  _CHATWITHTABLEBUILDERAGENTREQUEST.fields_by_name['message']._options = None
  _CHATWITHTABLEBUILDERAGENTREQUEST.fields_by_name['message']._serialized_options = b'\340A\002'
  _CHATWITHTABLEBUILDERAGENTRESPONSE.fields_by_name['event']._options = None
  _CHATWITHTABLEBUILDERAGENTRESPONSE.fields_by_name['event']._serialized_options = b'\340A\003'
  _CHATEVENT.fields_by_name['event']._options = None
  _CHATEVENT.fields_by_name['event']._serialized_options = b'\340A\003'
  _CHATEVENT.fields_by_name['id']._options = None
  _CHATEVENT.fields_by_name['id']._serialized_options = b'\340A\003'
  _CHATSTARTEDEVENT.fields_by_name['create_time']._options = None
  _CHATSTARTEDEVENT.fields_by_name['create_time']._serialized_options = b'\340A\003'
  _CHATSTATUSUPDATEDEVENT.fields_by_name['create_time']._options = None
  _CHATSTATUSUPDATEDEVENT.fields_by_name['create_time']._serialized_options = b'\340A\003'
  _CHATSTATUSUPDATEDEVENT.fields_by_name['chat_status']._options = None
  _CHATSTATUSUPDATEDEVENT.fields_by_name['chat_status']._serialized_options = b'\340A\003'
  _CHATOUTPUTUPDATEDEVENT.fields_by_name['create_time']._options = None
  _CHATOUTPUTUPDATEDEVENT.fields_by_name['create_time']._serialized_options = b'\340A\003'
  _CHATOUTPUTUPDATEDEVENT.fields_by_name['output_chunk_delta']._options = None
  _CHATOUTPUTUPDATEDEVENT.fields_by_name['output_chunk_delta']._serialized_options = b'\340A\003\340A\002'
  _CHATNAMEUPDATEDEVENT.fields_by_name['create_time']._options = None
  _CHATNAMEUPDATEDEVENT.fields_by_name['create_time']._serialized_options = b'\340A\003'
  _CHATNAMEUPDATEDEVENT.fields_by_name['name']._options = None
  _CHATNAMEUPDATEDEVENT.fields_by_name['name']._serialized_options = b'\340A\003'
  _CHATREPLANTRIGGEREDEVENT.fields_by_name['create_time']._options = None
  _CHATREPLANTRIGGEREDEVENT.fields_by_name['create_time']._serialized_options = b'\340A\003'
  _CHATREPLANTRIGGEREDEVENT.fields_by_name['number_of_replan']._options = None
  _CHATREPLANTRIGGEREDEVENT.fields_by_name['number_of_replan']._serialized_options = b'\340A\003'
  _CHATCITATIONLISTUPDATEDEVENT.fields_by_name['create_time']._options = None
  _CHATCITATIONLISTUPDATEDEVENT.fields_by_name['create_time']._serialized_options = b'\340A\003'
  _CHATCITATIONLISTUPDATEDEVENT.fields_by_name['citations']._options = None
  _CHATCITATIONLISTUPDATEDEVENT.fields_by_name['citations']._serialized_options = b'\340A\003\340A\002'
  _CHATATTACHMENTSUPDATEDEVENT.fields_by_name['create_time']._options = None
  _CHATATTACHMENTSUPDATEDEVENT.fields_by_name['create_time']._serialized_options = b'\340A\003'
  _CHATATTACHMENTSUPDATEDEVENT.fields_by_name['attachments']._options = None
  _CHATATTACHMENTSUPDATEDEVENT.fields_by_name['attachments']._serialized_options = b'\340A\003'
  _CHATCONTEXTUPDATEDEVENT.fields_by_name['create_time']._options = None
  _CHATCONTEXTUPDATEDEVENT.fields_by_name['create_time']._serialized_options = b'\340A\003'
  _CHATCONTEXTUPDATEDEVENT.fields_by_name['context']._options = None
  _CHATCONTEXTUPDATEDEVENT.fields_by_name['context']._serialized_options = b'\340A\003'
  _CHATTABLECREATEDEVENT_COLUMNDEFINITIONSENTRY._options = None
  _CHATTABLECREATEDEVENT_COLUMNDEFINITIONSENTRY._serialized_options = b'8\001'
  _CHATTABLECREATEDEVENT.fields_by_name['create_time']._options = None
  _CHATTABLECREATEDEVENT.fields_by_name['create_time']._serialized_options = b'\340A\003'
  _CHATTABLECREATEDEVENT.fields_by_name['table_uid']._options = None
  _CHATTABLECREATEDEVENT.fields_by_name['table_uid']._serialized_options = b'\340A\003'
  _CHATTABLECREATEDEVENT.fields_by_name['table']._options = None
  _CHATTABLECREATEDEVENT.fields_by_name['table']._serialized_options = b'\340A\003'
  _CHATTABLECREATEDEVENT.fields_by_name['column_definitions']._options = None
  _CHATTABLECREATEDEVENT.fields_by_name['column_definitions']._serialized_options = b'\340A\003'
  _CHATTABLEUPDATEDEVENT_COLUMNDEFINITIONSENTRY._options = None
  _CHATTABLEUPDATEDEVENT_COLUMNDEFINITIONSENTRY._serialized_options = b'8\001'
  _CHATTABLEUPDATEDEVENT.fields_by_name['create_time']._options = None
  _CHATTABLEUPDATEDEVENT.fields_by_name['create_time']._serialized_options = b'\340A\003'
  _CHATTABLEUPDATEDEVENT.fields_by_name['table_uid']._options = None
  _CHATTABLEUPDATEDEVENT.fields_by_name['table_uid']._serialized_options = b'\340A\003'
  _CHATTABLEUPDATEDEVENT.fields_by_name['table']._options = None
  _CHATTABLEUPDATEDEVENT.fields_by_name['table']._serialized_options = b'\340A\003'
  _CHATTABLEUPDATEDEVENT.fields_by_name['column_definitions']._options = None
  _CHATTABLEUPDATEDEVENT.fields_by_name['column_definitions']._serialized_options = b'\340A\003'
  _CHATERRORUPDATEDEVENT.fields_by_name['create_time']._options = None
  _CHATERRORUPDATEDEVENT.fields_by_name['create_time']._serialized_options = b'\340A\003'
  _CHATERRORUPDATEDEVENT.fields_by_name['error_type']._options = None
  _CHATERRORUPDATEDEVENT.fields_by_name['error_type']._serialized_options = b'\340A\003'
  _CHATERRORUPDATEDEVENT.fields_by_name['error']._options = None
  _CHATERRORUPDATEDEVENT.fields_by_name['error']._serialized_options = b'\340A\003'
  _CHATDEBUGOUTPUTUPDATEDEVENT.fields_by_name['create_time']._options = None
  _CHATDEBUGOUTPUTUPDATEDEVENT.fields_by_name['create_time']._serialized_options = b'\340A\003'
  _CHATDEBUGOUTPUTUPDATEDEVENT.fields_by_name['debug_output']._options = None
  _CHATDEBUGOUTPUTUPDATEDEVENT.fields_by_name['debug_output']._serialized_options = b'\340A\003'
  _CHATENDEDEVENT.fields_by_name['create_time']._options = None
  _CHATENDEDEVENT.fields_by_name['create_time']._serialized_options = b'\340A\003'
  _globals['_AGENTCONFIG']._serialized_start=219
  _globals['_AGENTCONFIG']._serialized_end=427
  _globals['_AGENTCONFIG_CONNECTIONSENTRY']._serialized_start=365
  _globals['_AGENTCONFIG_CONNECTIONSENTRY']._serialized_end=427
  _globals['_CHAT']._serialized_start=430
  _globals['_CHAT']._serialized_end=858
  _globals['_MESSAGE']._serialized_start=861
  _globals['_MESSAGE']._serialized_end=1548
  _globals['_MESSAGE_MESSAGETYPE']._serialized_start=1482
  _globals['_MESSAGE_MESSAGETYPE']._serialized_end=1548
  _globals['_CHATCONTEXT']._serialized_start=1550
  _globals['_CHATCONTEXT']._serialized_end=1599
  _globals['_CHATATTACHMENTS']._serialized_start=1601
  _globals['_CHATATTACHMENTS']._serialized_end=1652
  _globals['_CREATECHATREQUEST']._serialized_start=1655
  _globals['_CREATECHATREQUEST']._serialized_end=1875
  _globals['_CREATECHATRESPONSE']._serialized_start=1877
  _globals['_CREATECHATRESPONSE']._serialized_end=1949
  _globals['_LISTCHATSREQUEST']._serialized_start=1952
  _globals['_LISTCHATSREQUEST']._serialized_end=2140
  _globals['_LISTCHATSRESPONSE']._serialized_start=2143
  _globals['_LISTCHATSRESPONSE']._serialized_end=2297
  _globals['_UPDATECHATREQUEST']._serialized_start=2300
  _globals['_UPDATECHATREQUEST']._serialized_end=2509
  _globals['_UPDATECHATRESPONSE']._serialized_start=2511
  _globals['_UPDATECHATRESPONSE']._serialized_end=2583
  _globals['_GETCHATREQUEST']._serialized_start=2585
  _globals['_GETCHATREQUEST']._serialized_end=2673
  _globals['_GETCHATRESPONSE']._serialized_start=2675
  _globals['_GETCHATRESPONSE']._serialized_end=2744
  _globals['_DELETECHATREQUEST']._serialized_start=2746
  _globals['_DELETECHATREQUEST']._serialized_end=2837
  _globals['_DELETECHATRESPONSE']._serialized_start=2839
  _globals['_DELETECHATRESPONSE']._serialized_end=2859
  _globals['_MESSAGESENDERPROFILE']._serialized_start=2862
  _globals['_MESSAGESENDERPROFILE']._serialized_end=3075
  _globals['_LISTMESSAGESREQUEST']._serialized_start=3078
  _globals['_LISTMESSAGESREQUEST']._serialized_end=3269
  _globals['_LISTMESSAGESRESPONSE']._serialized_start=3272
  _globals['_LISTMESSAGESRESPONSE']._serialized_end=3527
  _globals['_CHATWITHAGENTREQUEST']._serialized_start=3530
  _globals['_CHATWITHAGENTREQUEST']._serialized_end=3843
  _globals['_CHATWITHAGENTRESPONSE']._serialized_start=3845
  _globals['_CHATWITHAGENTRESPONSE']._serialized_end=3924
  _globals['_TABLEBUILDERAGENTMESSAGE']._serialized_start=3926
  _globals['_TABLEBUILDERAGENTMESSAGE']._serialized_end=3983
  _globals['_LISTTABLEBUILDERAGENTMESSAGESREQUEST']._serialized_start=3986
  _globals['_LISTTABLEBUILDERAGENTMESSAGESREQUEST']._serialized_end=4196
  _globals['_LISTTABLEBUILDERAGENTMESSAGESRESPONSE']._serialized_start=4199
  _globals['_LISTTABLEBUILDERAGENTMESSAGESRESPONSE']._serialized_end=4471
  _globals['_CHATWITHTABLEBUILDERAGENTREQUEST']._serialized_start=4474
  _globals['_CHATWITHTABLEBUILDERAGENTREQUEST']._serialized_end=4613
  _globals['_CHATWITHTABLEBUILDERAGENTRESPONSE']._serialized_start=4615
  _globals['_CHATWITHTABLEBUILDERAGENTRESPONSE']._serialized_end=4709
  _globals['_CHATEVENT']._serialized_start=4712
  _globals['_CHATEVENT']._serialized_end=6157
  _globals['_CHATSTARTEDEVENT']._serialized_start=6159
  _globals['_CHATSTARTEDEVENT']._serialized_end=6243
  _globals['_CHATSTATUSUPDATEDEVENT']._serialized_start=6246
  _globals['_CHATSTATUSUPDATEDEVENT']._serialized_end=6374
  _globals['_CHATOUTPUTUPDATEDEVENT']._serialized_start=6377
  _globals['_CHATOUTPUTUPDATEDEVENT']._serialized_end=6521
  _globals['_CHATNAMEUPDATEDEVENT']._serialized_start=6523
  _globals['_CHATNAMEUPDATEDEVENT']._serialized_end=6636
  _globals['_CHATREPLANTRIGGEREDEVENT']._serialized_start=6639
  _globals['_CHATREPLANTRIGGEREDEVENT']._serialized_end=6778
  _globals['_CHATCITATIONLISTUPDATEDEVENT']._serialized_start=6781
  _globals['_CHATCITATIONLISTUPDATEDEVENT']._serialized_end=6946
  _globals['_CHATATTACHMENTSUPDATEDEVENT']._serialized_start=6949
  _globals['_CHATATTACHMENTSUPDATEDEVENT']._serialized_end=7121
  _globals['_CHATCONTEXTUPDATEDEVENT']._serialized_start=7124
  _globals['_CHATCONTEXTUPDATEDEVENT']._serialized_end=7280
  _globals['_CHATTABLECREATEDEVENT']._serialized_start=7283
  _globals['_CHATTABLECREATEDEVENT']._serialized_end=7689
  _globals['_CHATTABLECREATEDEVENT_COLUMNDEFINITIONSENTRY']._serialized_start=7582
  _globals['_CHATTABLECREATEDEVENT_COLUMNDEFINITIONSENTRY']._serialized_end=7689
  _globals['_CHATTABLEUPDATEDEVENT']._serialized_start=7692
  _globals['_CHATTABLEUPDATEDEVENT']._serialized_end=8098
  _globals['_CHATTABLEUPDATEDEVENT_COLUMNDEFINITIONSENTRY']._serialized_start=7582
  _globals['_CHATTABLEUPDATEDEVENT_COLUMNDEFINITIONSENTRY']._serialized_end=7689
  _globals['_CHATERRORUPDATEDEVENT']._serialized_start=8101
  _globals['_CHATERRORUPDATEDEVENT']._serialized_end=8253
  _globals['_CHATDEBUGOUTPUTUPDATEDEVENT']._serialized_start=8256
  _globals['_CHATDEBUGOUTPUTUPDATEDEVENT']._serialized_end=8391
  _globals['_CHATENDEDEVENT']._serialized_start=8393
  _globals['_CHATENDEDEVENT']._serialized_end=8475
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _CitationType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _CitationTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_CitationType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    CITATION_TYPE_UNSPECIFIED: _CitationType.ValueType  # 0
    """Unspecified citation type"""
    CITATION_TYPE_FILE: _CitationType.ValueType  # 1
    """file-based citation"""
    CITATION_TYPE_WEB: _CitationType.ValueType  # 2
    """web-based citation"""
    CITATION_TYPE_TABLE: _CitationType.ValueType  # 3
    """table-based citation"""

class CitationType(_CitationType, metaclass=_CitationTypeEnumTypeWrapper):
    """type of the citations message"""

CITATION_TYPE_UNSPECIFIED: CitationType.ValueType  # 0
"""Unspecified citation type"""
CITATION_TYPE_FILE: CitationType.ValueType  # 1
"""file-based citation"""
CITATION_TYPE_WEB: CitationType.ValueType  # 2
"""web-based citation"""
CITATION_TYPE_TABLE: CitationType.ValueType  # 3
"""table-based citation"""
global___CitationType = CitationType

class _CitationExtractMethodType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _CitationExtractMethodTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_CitationExtractMethodType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    CITATION_EXTRACT_METHOD_TYPE_UNSPECIFIED: _CitationExtractMethodType.ValueType  # 0
    """Unspecified citation extract method"""
    CITATION_EXTRACT_METHOD_TYPE_SELF: _CitationExtractMethodType.ValueType  # 1
    """self generated"""
    CITATION_EXTRACT_METHOD_TYPE_WEB: _CitationExtractMethodType.ValueType  # 2
    """extract from web search tool"""
    CITATION_EXTRACT_METHOD_TYPE_RAG: _CitationExtractMethodType.ValueType  # 3
    """extract from RAG tool"""
    CITATION_EXTRACT_METHOD_TYPE_DEEP_ANALYSIS: _CitationExtractMethodType.ValueType  # 4
    """extract from deep analysis tool"""

class CitationExtractMethodType(_CitationExtractMethodType, metaclass=_CitationExtractMethodTypeEnumTypeWrapper):
    """type of the citations message extract method"""

CITATION_EXTRACT_METHOD_TYPE_UNSPECIFIED: CitationExtractMethodType.ValueType  # 0
"""Unspecified citation extract method"""
CITATION_EXTRACT_METHOD_TYPE_SELF: CitationExtractMethodType.ValueType  # 1
"""self generated"""
CITATION_EXTRACT_METHOD_TYPE_WEB: CitationExtractMethodType.ValueType  # 2
"""extract from web search tool"""
CITATION_EXTRACT_METHOD_TYPE_RAG: CitationExtractMethodType.ValueType  # 3
"""extract from RAG tool"""
CITATION_EXTRACT_METHOD_TYPE_DEEP_ANALYSIS: CitationExtractMethodType.ValueType  # 4
"""extract from deep analysis tool"""
global___CitationExtractMethodType = CitationExtractMethodType

@typing_extensions.final
class Citation(google.protobuf.message.Message):
    """Citation message"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TYPE_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    URL_FIELD_NUMBER: builtins.int
    NUMBER_FIELD_NUMBER: builtins.int
    SUMMARY_FIELD_NUMBER: builtins.int
    EXTRACT_METHOD_FIELD_NUMBER: builtins.int
    type: global___CitationType.ValueType
    """Type of citation"""
    name: builtins.str
    """Name of the citation"""
    url: builtins.str
    """URL of the citation, can be web url, cell url or object-uid"""
    number: builtins.int
    """Citation number"""
    summary: builtins.str
    """File summary (only applicable for file type citations)"""
    extract_method: global___CitationExtractMethodType.ValueType
    """Citation extract method type"""
    def __init__(
        self,
        *,
        type: global___CitationType.ValueType = ...,
        name: builtins.str = ...,
        url: builtins.str = ...,
        number: builtins.int = ...,
        summary: builtins.str | None = ...,
        extract_method: global___CitationExtractMethodType.ValueType = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["_summary", b"_summary", "summary", b"summary"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["_summary", b"_summary", "extract_method", b"extract_method", "name", b"name", "number", b"number", "summary", b"summary", "type", b"type", "url", b"url"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_summary", b"_summary"]) -> typing_extensions.Literal["summary"] | None: ...

global___Citation = Citation



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _FileMediaType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _FileMediaTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_FileMediaType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    FILE_MEDIA_TYPE_UNSPECIFIED: _FileMediaType.ValueType  # 0
    """Unspecified."""
    FILE_MEDIA_TYPE_DOCUMENT: _FileMediaType.ValueType  # 1
    """Document."""
    FILE_MEDIA_TYPE_IMAGE: _FileMediaType.ValueType  # 2
    """Image."""
    FILE_MEDIA_TYPE_AUDIO: _FileMediaType.ValueType  # 3
    """Audio."""
    FILE_MEDIA_TYPE_VIDEO: _FileMediaType.ValueType  # 4
    """Video."""

class FileMediaType(_FileMediaType, metaclass=_FileMediaTypeEnumTypeWrapper):
    """FileMediaType describes the type of a catalog file."""

FILE_MEDIA_TYPE_UNSPECIFIED: FileMediaType.ValueType  # 0
"""Unspecified."""
FILE_MEDIA_TYPE_DOCUMENT: FileMediaType.ValueType  # 1
"""Document."""
FILE_MEDIA_TYPE_IMAGE: FileMediaType.ValueType  # 2
"""Image."""
FILE_MEDIA_TYPE_AUDIO: FileMediaType.ValueType  # 3
"""Audio."""
FILE_MEDIA_TYPE_VIDEO: FileMediaType.ValueType  # 4
"""Video."""
global___FileMediaType = FileMediaType

class _ContentType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _ContentTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_ContentType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    CONTENT_TYPE_UNSPECIFIED: _ContentType.ValueType  # 0
    """Unspecified."""
    CONTENT_TYPE_CHUNK: _ContentType.ValueType  # 1
    """Chunk."""
    CONTENT_TYPE_SUMMARY: _ContentType.ValueType  # 2
    """Summary."""
    CONTENT_TYPE_AUGMENTED: _ContentType.ValueType  # 3
    """Augmented."""

class ContentType(_ContentType, metaclass=_ContentTypeEnumTypeWrapper):
    """ContentType describes the type of a chunk content."""

CONTENT_TYPE_UNSPECIFIED: ContentType.ValueType  # 0
"""Unspecified."""
CONTENT_TYPE_CHUNK: ContentType.ValueType  # 1
"""Chunk."""
CONTENT_TYPE_SUMMARY: ContentType.ValueType  # 2
"""Summary."""
CONTENT_TYPE_AUGMENTED: ContentType.ValueType  # 3
"""Augmented."""
global___ContentType = ContentType

@typing_extensions.final
class Chunk(google.protobuf.message.Message):
    """The Chunk message represents a chunk of data in the artifact system."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CHUNK_UID_FIELD_NUMBER: builtins.int
    RETRIEVABLE_FIELD_NUMBER: builtins.int
    START_POS_FIELD_NUMBER: builtins.int
    END_POS_FIELD_NUMBER: builtins.int
    TOKENS_FIELD_NUMBER: builtins.int
    CREATE_TIME_FIELD_NUMBER: builtins.int
    ORIGINAL_FILE_UID_FIELD_NUMBER: builtins.int
    CONTENT_TYPE_FIELD_NUMBER: builtins.int
    chunk_uid: builtins.str
    """unique identifier of the chunk"""
    retrievable: builtins.bool
    """whether the chunk is retrievable"""
    start_pos: builtins.int
    """start position of the chunk in the source file"""
    end_pos: builtins.int
    """end position of the chunk in the source file"""
    tokens: builtins.int
    """tokens of the chunk"""
    @property
    def create_time(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """creation time of the chunk"""
    original_file_uid: builtins.str
    """original file unique identifier"""
    content_type: global___ContentType.ValueType
    """content type"""
    def __init__(
        self,
        *,
        chunk_uid: builtins.str = ...,
        retrievable: builtins.bool = ...,
        start_pos: builtins.int = ...,
        end_pos: builtins.int = ...,
        tokens: builtins.int = ...,
        create_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        original_file_uid: builtins.str = ...,
        content_type: global___ContentType.ValueType = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["create_time", b"create_time"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["chunk_uid", b"chunk_uid", "content_type", b"content_type", "create_time", b"create_time", "end_pos", b"end_pos", "original_file_uid", b"original_file_uid", "retrievable", b"retrievable", "start_pos", b"start_pos", "tokens", b"tokens"]) -> None: ...

global___Chunk = Chunk

@typing_extensions.final
class ListChunksRequest(google.protobuf.message.Message):
    """The ListChunksRequest message represents a request to list chunks in the artifact system.
    The response will be a list of chunks based on the request, i.e., response will
    have chunks of the file with file_uid and chunks specified in chunk_uids.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAMESPACE_ID_FIELD_NUMBER: builtins.int
    CATALOG_ID_FIELD_NUMBER: builtins.int
    FILE_UID_FIELD_NUMBER: builtins.int
    namespace_id: builtins.str
    """owner/namespace id (not uid)"""
    catalog_id: builtins.str
    """catalog id (not uid)"""
    file_uid: builtins.str
    """unique identifier of the file"""
    def __init__(
        self,
        *,
        namespace_id: builtins.str = ...,
        catalog_id: builtins.str = ...,
        file_uid: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["catalog_id", b"catalog_id", "file_uid", b"file_uid", "namespace_id", b"namespace_id"]) -> None: ...

global___ListChunksRequest = ListChunksRequest

@typing_extensions.final
class ListChunksResponse(google.protobuf.message.Message):
    """The ListChunksResponse message represents a response containing a list of chunks in the artifact system."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CHUNKS_FIELD_NUMBER: builtins.int
    @property
    def chunks(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Chunk]:
        """repeated chunks"""
    def __init__(
        self,
        *,
        chunks: collections.abc.Iterable[global___Chunk] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["chunks", b"chunks"]) -> None: ...

global___ListChunksResponse = ListChunksResponse

@typing_extensions.final
class SearchChunksRequest(google.protobuf.message.Message):
    """Search chunks request"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAMESPACE_ID_FIELD_NUMBER: builtins.int
    CHUNK_UIDS_FIELD_NUMBER: builtins.int
    namespace_id: builtins.str
    """owner/namespace id (not uid)"""
    @property
    def chunk_uids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """chunk uids"""
    def __init__(
        self,
        *,
        namespace_id: builtins.str = ...,
        chunk_uids: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["chunk_uids", b"chunk_uids", "namespace_id", b"namespace_id"]) -> None: ...

global___SearchChunksRequest = SearchChunksRequest

@typing_extensions.final
class SearchChunksResponse(google.protobuf.message.Message):
    """Search chunks response"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CHUNKS_FIELD_NUMBER: builtins.int
    @property
    def chunks(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Chunk]:
        """repeated chunks"""
    def __init__(
        self,
        *,
        chunks: collections.abc.Iterable[global___Chunk] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["chunks", b"chunks"]) -> None: ...

global___SearchChunksResponse = SearchChunksResponse

@typing_extensions.final
class SourceFile(google.protobuf.message.Message):
    """The SourceFile message represents a source file in the artifact system."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ORIGINAL_FILE_UID_FIELD_NUMBER: builtins.int
    CONTENT_FIELD_NUMBER: builtins.int
    CREATE_TIME_FIELD_NUMBER: builtins.int
    UPDATE_TIME_FIELD_NUMBER: builtins.int
    ORIGINAL_FILE_NAME_FIELD_NUMBER: builtins.int
    original_file_uid: builtins.str
    """original file unique identifier"""
    content: builtins.str
    """content"""
    @property
    def create_time(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """creation time of the source file"""
    @property
    def update_time(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """update time of the source file"""
    original_file_name: builtins.str
    """original file name"""
    def __init__(
        self,
        *,
        original_file_uid: builtins.str = ...,
        content: builtins.str = ...,
        create_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        update_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        original_file_name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["create_time", b"create_time", "update_time", b"update_time"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["content", b"content", "create_time", b"create_time", "original_file_name", b"original_file_name", "original_file_uid", b"original_file_uid", "update_time", b"update_time"]) -> None: ...

global___SourceFile = SourceFile

@typing_extensions.final
class GetSourceFileRequest(google.protobuf.message.Message):
    """get source file request"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAMESPACE_ID_FIELD_NUMBER: builtins.int
    CATALOG_ID_FIELD_NUMBER: builtins.int
    FILE_UID_FIELD_NUMBER: builtins.int
    namespace_id: builtins.str
    """owner/namespace id"""
    catalog_id: builtins.str
    """catalog id"""
    file_uid: builtins.str
    """unique identifier of the original uploaded file"""
    def __init__(
        self,
        *,
        namespace_id: builtins.str = ...,
        catalog_id: builtins.str = ...,
        file_uid: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["catalog_id", b"catalog_id", "file_uid", b"file_uid", "namespace_id", b"namespace_id"]) -> None: ...

global___GetSourceFileRequest = GetSourceFileRequest

@typing_extensions.final
class GetSourceFileResponse(google.protobuf.message.Message):
    """get source file response"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SOURCE_FILE_FIELD_NUMBER: builtins.int
    @property
    def source_file(self) -> global___SourceFile:
        """source file(either original file or converted file)"""
    def __init__(
        self,
        *,
        source_file: global___SourceFile | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["source_file", b"source_file"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["source_file", b"source_file"]) -> None: ...

global___GetSourceFileResponse = GetSourceFileResponse

@typing_extensions.final
class GetFileSummaryRequest(google.protobuf.message.Message):
    """get file summary request"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAMESPACE_ID_FIELD_NUMBER: builtins.int
    CATALOG_ID_FIELD_NUMBER: builtins.int
    FILE_UID_FIELD_NUMBER: builtins.int
    namespace_id: builtins.str
    """owner/namespace id"""
    catalog_id: builtins.str
    """catalog id"""
    file_uid: builtins.str
    """unique identifier of the original uploaded file"""
    def __init__(
        self,
        *,
        namespace_id: builtins.str = ...,
        catalog_id: builtins.str = ...,
        file_uid: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["catalog_id", b"catalog_id", "file_uid", b"file_uid", "namespace_id", b"namespace_id"]) -> None: ...

global___GetFileSummaryRequest = GetFileSummaryRequest

@typing_extensions.final
class GetFileSummaryResponse(google.protobuf.message.Message):
    """get file summary response"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SUMMARY_FIELD_NUMBER: builtins.int
    summary: builtins.str
    """summary of the file"""
    def __init__(
        self,
        *,
        summary: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["summary", b"summary"]) -> None: ...

global___GetFileSummaryResponse = GetFileSummaryResponse

@typing_extensions.final
class SearchSourceFilesRequest(google.protobuf.message.Message):
    """search source file request"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAMESPACE_ID_FIELD_NUMBER: builtins.int
    FILE_UIDS_FIELD_NUMBER: builtins.int
    namespace_id: builtins.str
    """owner/namespace id"""
    @property
    def file_uids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """search file uid"""
    def __init__(
        self,
        *,
        namespace_id: builtins.str = ...,
        file_uids: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["file_uids", b"file_uids", "namespace_id", b"namespace_id"]) -> None: ...

global___SearchSourceFilesRequest = SearchSourceFilesRequest

@typing_extensions.final
class SearchSourceFilesResponse(google.protobuf.message.Message):
    """search source file response"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SOURCE_FILES_FIELD_NUMBER: builtins.int
    @property
    def source_files(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SourceFile]:
        """source files"""
    def __init__(
        self,
        *,
        source_files: collections.abc.Iterable[global___SourceFile] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["source_files", b"source_files"]) -> None: ...

global___SearchSourceFilesResponse = SearchSourceFilesResponse

@typing_extensions.final
class UpdateChunkRequest(google.protobuf.message.Message):
    """Create chunk response"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CHUNK_UID_FIELD_NUMBER: builtins.int
    RETRIEVABLE_FIELD_NUMBER: builtins.int
    chunk_uid: builtins.str
    """chunk uid"""
    retrievable: builtins.bool
    """whether the chunk is retrievable"""
    def __init__(
        self,
        *,
        chunk_uid: builtins.str = ...,
        retrievable: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["chunk_uid", b"chunk_uid", "retrievable", b"retrievable"]) -> None: ...

global___UpdateChunkRequest = UpdateChunkRequest

@typing_extensions.final
class UpdateChunkResponse(google.protobuf.message.Message):
    """update chunk response"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CHUNK_FIELD_NUMBER: builtins.int
    @property
    def chunk(self) -> global___Chunk:
        """chunk"""
    def __init__(
        self,
        *,
        chunk: global___Chunk | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["chunk", b"chunk"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["chunk", b"chunk"]) -> None: ...

global___UpdateChunkResponse = UpdateChunkResponse

@typing_extensions.final
class SimilarityChunksSearchRequest(google.protobuf.message.Message):
    """Similar chunk search request"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAMESPACE_ID_FIELD_NUMBER: builtins.int
    CATALOG_ID_FIELD_NUMBER: builtins.int
    TEXT_PROMPT_FIELD_NUMBER: builtins.int
    TOP_K_FIELD_NUMBER: builtins.int
    FILE_NAME_FIELD_NUMBER: builtins.int
    CONTENT_TYPE_FIELD_NUMBER: builtins.int
    FILE_MEDIA_TYPE_FIELD_NUMBER: builtins.int
    namespace_id: builtins.str
    """owner/namespace id"""
    catalog_id: builtins.str
    """catalog id"""
    text_prompt: builtins.str
    """text prompt"""
    top_k: builtins.int
    """top k"""
    file_name: builtins.str
    """file name"""
    content_type: global___ContentType.ValueType
    """content type"""
    file_media_type: global___FileMediaType.ValueType
    """file type"""
    def __init__(
        self,
        *,
        namespace_id: builtins.str = ...,
        catalog_id: builtins.str = ...,
        text_prompt: builtins.str = ...,
        top_k: builtins.int = ...,
        file_name: builtins.str = ...,
        content_type: global___ContentType.ValueType = ...,
        file_media_type: global___FileMediaType.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["catalog_id", b"catalog_id", "content_type", b"content_type", "file_media_type", b"file_media_type", "file_name", b"file_name", "namespace_id", b"namespace_id", "text_prompt", b"text_prompt", "top_k", b"top_k"]) -> None: ...

global___SimilarityChunksSearchRequest = SimilarityChunksSearchRequest

@typing_extensions.final
class SimilarityChunksSearchResponse(google.protobuf.message.Message):
    """Similar chunk search response"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SIMILAR_CHUNKS_FIELD_NUMBER: builtins.int
    @property
    def similar_chunks(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SimilarityChunk]:
        """chunks"""
    def __init__(
        self,
        *,
        similar_chunks: collections.abc.Iterable[global___SimilarityChunk] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["similar_chunks", b"similar_chunks"]) -> None: ...

global___SimilarityChunksSearchResponse = SimilarityChunksSearchResponse

@typing_extensions.final
class SimilarityChunk(google.protobuf.message.Message):
    """similarity chunks"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CHUNK_UID_FIELD_NUMBER: builtins.int
    SIMILARITY_SCORE_FIELD_NUMBER: builtins.int
    TEXT_CONTENT_FIELD_NUMBER: builtins.int
    SOURCE_FILE_FIELD_NUMBER: builtins.int
    CHUNK_METADATA_FIELD_NUMBER: builtins.int
    chunk_uid: builtins.str
    """chunk uid"""
    similarity_score: builtins.float
    """similarity score"""
    text_content: builtins.str
    """content"""
    source_file: builtins.str
    """source file's name"""
    @property
    def chunk_metadata(self) -> global___Chunk:
        """chunk"""
    def __init__(
        self,
        *,
        chunk_uid: builtins.str = ...,
        similarity_score: builtins.float = ...,
        text_content: builtins.str = ...,
        source_file: builtins.str = ...,
        chunk_metadata: global___Chunk | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["chunk_metadata", b"chunk_metadata"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["chunk_metadata", b"chunk_metadata", "chunk_uid", b"chunk_uid", "similarity_score", b"similarity_score", "source_file", b"source_file", "text_content", b"text_content"]) -> None: ...

global___SimilarityChunk = SimilarityChunk
